.onLoad <- function(libname, pkgname) {
  extdata_dirpath <- system.file("extdata", package=pkgname,
                                 lib.loc=libname, mustWork=TRUE)

  ## Load GenomeDescription object frozen from BSgenome.Hsapiens.1000genomes.hs37d5
  rg <- readRDS(file.path(extdata_dirpath, "refgenomeGD.rds"))

  ## Make and export MafDb2 object.
  espmaf <- MafDb2(provider="NHLBIESP",
                   provider_version="ESP6500SI-V2",
                   download_url="http://evs.gs.washington.edu/EVS",
                   download_date="Sep 30, 2016",
                   reference_genome=rg,
                   rsIDgpSNVs=GPos(), ## rsIDgpSNVs, (loaded only later if mafById() is called)
                   rsIDSNVs=integer(0), ## rsIDSNVs, (loaded only later if mafById() is called)
                   rsIDidxSNVs=integer(0), ## rsIDidxSNVs, (loaded only later if mafById() is called)
                   data_pkgname=pkgname,
                   data_dirpath=extdata_dirpath)

  ns <- asNamespace(pkgname)

  objname <- pkgname
  assign(objname, espmaf, envir=ns)

  namespaceExport(ns, objname)
}

.onAttach <- function(libname, pkgname) {
  msg <- paste("WARNING: The positions associated to the MAF data stored in the",
               sprintf("%s package are based on the GRCh38", pkgname),
               "release of the human genome and they were lifted by the NHLBI ESP",
               "from GRCh37. This means, the variants were not called directly on the",
               "GRCh38 human genome reference sequence.", sep="\n")
  packageStartupMessage(msg)
}
