\name{MafDb.ESP6500SI.V2.SSA137.GRCh38-package}
\alias{MafDb.ESP6500SI.V2.SSA137.GRCh38-package}
\alias{MafDb.ESP6500SI.V2.SSA137.GRCh38}
\docType{package}

\title{
Annotation package for minor allele frequency data from the NHLBI ESP project
}
\description{
This annotation package stores minor allele frequency (MAF) data values from the release ESP6500SI-V2 of the NHLBI Exome Sequencing project (ESP). The data is loaded automatically in the form of a \code{MafDb2} object. The name of the exposed object matches the name of the package and part of the filename that contained the data imported into the package. The class definition and methods to access MafDb2 objects are found in the \code{\link[VariantFiltering]{VariantFiltering}} software package.

WARNING: The positions associated to these MAF data are based on the
GRCh38 release of the human genome and they were lifted by the NHLBI ESP
from GRCh37. This means, the variants were not called directly on the
GRCh38 human genome reference sequence.
}

\format{
  \tabular{ll}{
    \code{\link{MafDb.ESP6500SI.V2.SSA137.GRCh38}} \tab MafDb object containing MAF values from 6503 exomes downloaded in September 2016 from \url{http://evs.gs.washington.edu/evs_bulk_data/ESP6500SI-V2-SSA137.GRCh38-liftover.snps_indels.vcf.tar.gz}. See the \code{inst/extdata/README} file from the source code for more information on how to update these data. \cr
  }
}

\author{
R. Castelo
}

\seealso{
  \link[MafDb.1Kgenomes.phase1.hs37d5]{MafDb.1Kgenomes.phase1.hs37d5}
  \link[MafDb.1Kgenomes.phase3.hs37d5]{MafDb.1Kgenomes.phase3.hs37d5}
  \link[VariantFiltering]{MafDb2-class}
  \link[VariantFiltering]{mafByOverlaps}
  \link[VariantFiltering]{mafById}
  \link[VariantFiltering]{VariantFiltering}
}

\examples{
library(MafDb.ESP6500SI.V2.SSA137.GRCh38)

ls("package:MafDb.ESP6500SI.V2.SSA137.GRCh38")

mafdb <- MafDb.ESP6500SI.V2.SSA137.GRCh38
mafdb

populations(mafdb)

## lookup allele frequencies for rs1129038, an SNP associated to blue and brown eye colors
## as reported in Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]
rng <- GRanges("15", IRanges(28111713, 28111713))
mafByOverlaps(mafdb, rng)
mafByOverlaps(mafdb, "15:28111713-28111713")
mafByOverlaps(mafdb, "15:28111713")
mafById(mafdb, "rs1129038")
}

\source{
  Tennessen JA, et al. Evolution and functional impact of rare coding
  variation from deep sequencing of human exomes. Science, 337:64-69, 2012.

  Exome Variant Server, NHLBI GO Exome Sequencing Project (ESP), Seattle, WA
  (URL: \url{http://evs.gs.washington.edu/EVS}) [September, 2016, accessed]
}

\keyword{package}
\keyword{data}
